@@ -51,6 +51,10 @@ def test_generate_header_strings(python_build:PythonBuild):
     file_header:List[str] = python_build.generate_config_header()
     assert file_header[1]  == 'Config file built from yaml\n'
 
+def test_generate_exteral_imports(python_build:PythonBuild, yaml_ops:YAMLOperations):
+    lines: List[str] = python_build.generate_external_imports(external_attrs=yaml_ops.nut.external_imports)
+    assert lines[0]  == 'from serena.utilities.ensemble_structures import Sara2SecondaryStructure\n'
+
 def test_build_nut_enum(python_build:PythonBuild, yaml_ops:YAMLOperations):
     lines: List[str] = python_build.generate_nut_enums(nut_structure=yaml_ops.nut)
     assert lines[1] == '\tPrimaryStructure = "primary_structure_db"\n'
@@ -140,11 +144,12 @@ def test_build_one_file_api(python_build:PythonBuild, yaml_ops:YAMLOperations):
     full_list:List[str] = []
     nut_struct_name:str = "NupackStrand"
     header_list:List[str] = python_build.generate_one_file_api_header()
+    external_links_list:List[str] = python_build.generate_external_imports(external_attrs=yaml_ops.nut.external_imports)
     enum_lines: List[str] = python_build.generate_nut_enums(nut_structure=yaml_ops.nut)
     basecode_lines:List[str] = python_build.generate_config_baseclass(class_name=nut_struct_name,
                                                        container_definitions=yaml_ops.definitions,
                                                        nut_structure=yaml_ops.nut)
-    full_list:List[str] = header_list + enum_lines + basecode_lines
+    full_list:List[str] = header_list + external_links_list + enum_lines + basecode_lines
     found_structs_list:List[str] = []
     yaml_ops.reset_priority_queue
     while len(yaml_ops.priority_queue) > 0:
